@@ -2,4 +2,4 @@
 use strict;
 use Diff::Text;
 
-print text_diff($ARGV[0],$ARGV[1]);
\ No newline at end of file
+print text_diff($ARGV[0],$ARGV[1],{plain=>1});
